<?php
// $Id: chat.php,v 1.1.1.2 2003/01/09 11:20:57 nanasess Exp $
session_name("CHATSESS");
session_start();
if (isset($_SESSION["cook"]) && $_SESSION["cook"] == 1) {
  session_set_cookie_params(60*60*24*30*3+time(), "./");
} else {
  session_set_cookie_params(0, "./");
}
$include_path = "./include";
require_once $include_path . "/chat.inc";
$nChat = new myChatPref;
$db = new myDB_Sql;
$myChat = new Chat;
?>
<?xml version="1.0" encoding="EUC-JP" ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title><?php $nChat->PrintTitle(); ?></title>
<meta http-equiv="Content-Type" content="text/html; charset=EUC-JP" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<link rel="stylesheet" type="text/css" href="basic.css" />
<?php
if (isset($_GET["W"])) { // ⡼ɤϥɤʤ
  ;
} elseif (isset($_GET["out"])) { // ༼ϥɤʤ
  ;
} else {
  if ($_POST["chat"] != "") {
	$_SESSION["R"] = $_SESSION["RD"]; // ȯɤ
  }
  $myChat->AutoReloadLog();
}
print("</head>\n");
print("<body>\n");
print("<div class=\"size10px\">");
$db->dbObj->query("BEGIN");
$myChat->reloadLog();
$myChat->sanka();
$db->dbObj->query("COMMIT");
print("</div>\n");
if (isset($_GET["out"])) {
	$myChat->outLog();
    if (empty($_SESSION["R"])) {
        $_SESSION["R"] = "";
    }
}

if ($_POST["chat"] != "") {
  $myChat->writeLog(); // 񤭹
} else {
  $myChat->reload();
}
$db->dbObj->query("BEGIN");
$myChat->getLogData();
$myChat->printFooter();
$db->dbObj->query("COMMIT");
?>
</body>
</html>
<?php
if (isset($_GET["out"])) {
    unset($_SESSION["R"]);
}
?>
